.. _integration-guides:

==================
Integration Guides
==================

Integrations provide a friendly way for an application to allow users to
link up with multiple services. An application can provide support for any
number of integrations, and give users a way to manage them.

These guides will cover how to support and write integrations.


.. toctree::
   :maxdepth: 2

   supporting-integrations
   writing-integrations
